@@ -10,7 +10,7 @@ use IO::Socket::IP -register;
 use IO::Socket::SSL;
 use Time::Crontab;
 
-our $VERSION = '1.33'; # VERSION
+our $VERSION = '1.34'; # VERSION
 
 sub new {
     my $class = shift;
@@ -161,17 +161,7 @@ sub _parent {
             chomp($line);
 
             if ( not $session->{established} ) {
-                if ( $line =~ /^ERROR.+onnect\w+ too fast/ ) {
-                    warn "$line\n";
-                    warn "Sleeping 20 and retrying...\n";
-                    sleep 20;
-                    $device->daemon->do_restart;
-                }
-                elsif ( $line =~ /^ERROR\s/ ) {
-                    warn "$line\n";
-                    $device->daemon->do_stop;
-                }
-                elsif ( not $session->{user} ) {
+                if ( not $session->{user} ) {
                     if ( $self->{send_user_nick} eq 'on_reply' ) {
                         $self->say("USER $self->{nick} 0 * :$self->{connect}{name}");
                         $self->say("NICK $self->{nick}");
@@ -182,6 +172,16 @@ sub _parent {
                     }
                     $session->{user} = 1;
                 }
+                if ( $line =~ /^ERROR.+onnect\w+ too fast/ ) {
+                    warn "$line\n";
+                    warn "Sleeping 20 and retrying...\n";
+                    sleep 20;
+                    $device->daemon->do_restart;
+                }
+                elsif ( $line =~ /^ERROR\s/ ) {
+                    warn "$line\n";
+                    $device->daemon->do_stop;
+                }
                 elsif ( $line =~ /^:\S+\s433\s/ ) {
                     $self->nick( $self->{nick} . '_' );
                 }
@@ -680,7 +680,7 @@ Bot::IRC - Yet Another IRC Bot
 
 =head1 VERSION
 
-version 1.33
+version 1.34
 
 =for markdown [![test](https://github.com/gryphonshafer/Bot-IRC/workflows/test/badge.svg)](https://github.com/gryphonshafer/Bot-IRC/actions?query=workflow%3Atest)
 [![codecov](https://codecov.io/gh/gryphonshafer/Bot-IRC/graph/badge.svg)](https://codecov.io/gh/gryphonshafer/Bot-IRC)
